/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.osgi.launcher.core;

import java.io.Serializable;

/**
 * Allow to wait before starting a given set of modules specified by a pattern.
 * @author Florent BENOIT
 */
public class DelayedBundlePattern implements Serializable {

    /**
     * Serial version UID for Serializable classes.
     */
    private static final long serialVersionUID = -7535692380895489149L;

    /**
     * Seconds to wait for these bundles.
     */
    private long secondsToWait = 0;

    /**
     * Pattern to use.
     */
    private String pattern = "";

    /**
     * Gets the pattern.
     * @return the pattern of the bundles.
     */
    public String getPattern() {
        return pattern;
    }

    /**
     * @return seconds to wait for the given pattern.
     */
    public long getSecondsToWait() {
        return secondsToWait;
    }
}
