/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.osgi.launcher.core;


/**
 * Describe a Maven 2 artifact.
 * @author Florent Benoit
 */
public class Module {

    /**
     * Group Id of this module.
     */
    private String groupId;

    /**
     * Artifact id of this module.
     */
    private String artifactId;

    /**
     * Version of this module.
     * Version may be retrieved from the dependency management.
     */
    private String version;

    /**
     * Type of the archive.
     */
    private String type;


    /**
     * Classifier of the archive.
     */
    private String classifier;

    /**
     * @return group id
     */
    public String getGroupId() {
        return groupId;
    }


    /**
     * Sets group id.
     * @param groupId given value
     */
    public void setGroupId(final String groupId) {
        this.groupId = groupId;
    }


    /**
     * @return the artifact id
     */
    public String getArtifactId() {
        return artifactId;
    }


    /**
     * Sets artifact id.
     * @param artifactId given value
     */
    public void setArtifactId(final String artifactId) {
        this.artifactId = artifactId;
    }


    /**
     * @return the version.
     */

    public String getVersion() {
        return version;
    }


    /**
     * Sets the version.
     * @param version given value
     */
    public void setVersion(final String version) {
        this.version = version;
    }


    /**
     * @return the type
     */
    public String getType() {
        return type;
    }

    /**
     * Sets the type.
     * @param type the given value
     */
    public void setType(final String type) {
        this.type = type;
    }

    /**
     * @return the classifier
     */
    public String getClassifier() {
        return classifier;
    }

    /**
     * Sets the classifier.
     * @param classifier the given value
     */
    public void setClassifier(final String classifier) {
        this.classifier = classifier;
    }

    /**
     * @return the string representation of this module
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder("Module[groupId=");
        sb.append(groupId);
        sb.append(", artifactId=");
        sb.append(artifactId);
        sb.append(", type=");
        sb.append(type);
        sb.append(", version=");
        sb.append(version);
        sb.append("]");
        return sb.toString();
    }
}
