/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.osgi.launcher.core;

import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;

import org.ow2.util.log.Log;
import org.ow2.util.log.LogFactory;

/**
 * Allows to trace errors/output of a process.
 */
public class ProcessLog implements Runnable {

    /**
     * Logger.
     */
    private Log logger = LogFactory.getLog(ProcessLog.class);

    /**
     * Input stream containing information.
     */
    private InputStream is;

    /**
     * Should send as error or debug message ?
     */
    private boolean isErrorMessage = false;

    /**
     * Constructor.
     * @param is given input stream
     * @param isErrorMessage Should send as error or debug message
     */
    public ProcessLog(final InputStream is, final boolean isErrorMessage) {
        this.is = is;
        this.isErrorMessage = isErrorMessage;
    }

    /**
     * Thread execution printing information received.
     */
    public void run() {
        try {
            BufferedReader br = new BufferedReader(new InputStreamReader(is));
            String str = null;
            while ((str = br.readLine()) != null) {
                if (isErrorMessage) {
                    logger.error("RemoteJVM: {0}", str);
                } else {
                    logger.info("RemoteJVM: {0}", cleanup(str));
                }
            }
            // close input stream
            is.close();
        } catch (Exception e) {
            logger.error("Cannot close stream", e);
        }
    }

    /**
     * Cleanup the given string by removing the beginning of the message if it is a known info message.
     * @param string the string to cleanup
     * @return the cleaned string
     */
    public String cleanup(final String string) {
        // If it contains " (I) ", remove the first arguments
        String updatedString = string;
        String infoLevel = " (I) ";
        int index = string.indexOf(infoLevel);
        if (index != -1) {
            updatedString = string.substring(index + infoLevel.length());
        }

        return updatedString;
    }

}
