/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.osgi.launcher.core;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.ow2.util.maven.osgi.launcher.api.ILauncher;
import org.ow2.util.maven.osgi.launcher.api.LauncherException;

/**
 * Stop an OSGi framework.
 * @author Florent BENOIT
 * @since 2.0.0
 */
@Mojo(name = "stop",
      defaultPhase = LifecyclePhase.POST_INTEGRATION_TEST)
public class StopMojo extends AbsMojo {

    /**
     * Stop the OSGi framework.
     * @throws MojoExecutionException if there is a failure.
     */
    @Override
    protected void doExecute() throws MojoExecutionException {

        // Get launcher
        ILauncher launcher = getLauncher();

        // Launch the framework with the given configuration
        try {
            launcher.stop();
        } catch (LauncherException e) {
            throw new MojoExecutionException("Cannot launch the framework");
        }
    }

}
