/**
 * Copyright 2008-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.maven.osgi.fwkslauncher.core;

import java.util.Iterator;

import org.apache.maven.plugins.annotations.LifecyclePhase;
import org.apache.maven.plugins.annotations.Mojo;
import org.apache.maven.plugins.annotations.Parameter;
import org.ow2.util.maven.osgi.launcher.api.ILauncher;

/**
 * Start OSGi frameworks.
 * @author eyindanga
 * @since 2.0.0
 */
@Mojo(name = "start",
      defaultPhase = LifecyclePhase.PRE_INTEGRATION_TEST)
public class StartMojo extends AbsMojo {

    /**
     * Framework to launch in parallel.
     * @since 2.0.0
     */
    @Parameter(property = "parallel",
               alias = "parallel")
    private Parallel toLaunchInParallel;


    /* (non-Javadoc)
     * @see org.ow2.cmi.osgi.launcher.core.AbsMojo#doExecute()
     */
    @Override
    protected void doExecute() throws Exception {
        for (Iterator<IFwksLauncher> iterator = launchers.iterator(); iterator.hasNext();) {
            ILauncher launcher = iterator.next();
                launcher.start();
        }
    }
    /**
     * @return the parallel
     */
    public Parallel getParallel() {
        return toLaunchInParallel;
    }
    /**
     * @param parallel the toLaunchInParallel to set
     */
    public void setParallel(final Parallel parallel) {
        this.toLaunchInParallel = parallel;
    }

}
